pub fn stacking_openings_for_matrix(
params: &SystemParams,
z_prism: &[EF],
matrix: &ColMajorMatrix<F>,
) -> Vec<EF> ⓘExpand description
Compute stacking openings for a single matrix at the given evaluation point.
pub fn stacking_openings_for_matrix(
params: &SystemParams,
z_prism: &[EF],
matrix: &ColMajorMatrix<F>,
) -> Vec<EF> ⓘCompute stacking openings for a single matrix at the given evaluation point.